@@ -8,21 +8,25 @@ import sys
 
 class DisplayInfo():
     def __init__(self):
-        # QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
-        # QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)      
-        self.app = QApplication(sys.argv)
-           
+   
         self.scale_factor = []
         self.display_info = []
+        # self.get_scale_factor()
         pass
-        
-    def get_scale_factor(self):
-        screens = self.app.screens()
+
+    def get_Qapp(self):
+        app = QApplication(sys.argv)
+        return app
+
+    def get_scale_factor(self, app):
+        # app = QApplication(sys.argv)
+        # app =1
+        screens = app.screens()
         for i, screen in enumerate(screens):
             logical_dpi = screen.logicalDotsPerInch()
             print(screen, logical_dpi)
             self.scale_factor.append(logical_dpi / 96.0)  # Based on Windows' standard DPI of 96
-            # print(f"Monitor {i+1}: Scale Factor = {self.scale_factors}")
+        #     # print(f"Monitor {i+1}: Scale Factor = {self.scale_factors}")
         return self.scale_factor
     
 
@@ -56,5 +60,5 @@ class DisplayInfo():
 #     # dis.print_scale_factors()
 #     # dis.print_screen_info()
 #     # print(dis.get_screen_info())
-#     print(dis.get_scale_factor())
+#     print(dis.get_scale_factor(dis.get_Qapp()))
     
\ No newline at end of file
